# Resources Module

The `resources` module is responsible for housing project scaffolds.

## Directories

### `starter_project.zip`

Produces the default project after running the `pyrgo init` or `pyrgo new` command for the CLI.
